summaryrefslogtreecommitdiffstats
path: root/chrome/browser/resources
diff options
context:
space:
mode:
authorwittman@chromium.org <wittman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-31 17:56:06 +0000
committerwittman@chromium.org <wittman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-31 17:56:06 +0000
commitae57a18e11170253cf2515738bbdd09c37000c8f (patch)
tree51dc5666607de0326c54d6b5d3ccce77c8b30afe /chrome/browser/resources
parent026c6c24bbfd4d69bdabf2971605f7ab6983322f (diff)
downloadchromium_src-ae57a18e11170253cf2515738bbdd09c37000c8f.zip
chromium_src-ae57a18e11170253cf2515738bbdd09c37000c8f.tar.gz
chromium_src-ae57a18e11170253cf2515738bbdd09c37000c8f.tar.bz2
Revert 212329 "Reland "Close web contents modal dialogs on conte..."
Causes several problems related to the print preview dialog: http://crbug.com/262023 http://crbug.com/262916 http://crbug.com/265427 > Reland "Close web contents modal dialogs on content load start" > > Address the failure of some web contents modal dialogs to close when > interstitial WebUI is displayed by closing the dialogs on content load start. > Remove existing ad hoc support in dialogs for closing on page loading in favor > of a uniform approach. > > I'm using load start as the trigger for dialog close as this seems to be the > point in time at which the user first perceives the page to be changing. > > Notes on the print preview changes: with this change the dialog is closed when > load starts and the initiator tab gets removed via RemovePreviewDialog, so there > is no longer a need to handle NOTIFICATION_NAV_ENTRY_COMITTED for the initiator > tab. The PrintViewManager::PrintPreviewDone() DCHECK is removed since now > PrintViewManager::RenderViewGone() may be invoked and print_preview_state_ reset > due to WebContents closure before the dialog is destroyed and PrintPreviewDone() > is invoked. > > BUG=240575 > > Committed: https://src.chromium.org/viewvc/chrome?view=rev&revision=211058 > > Review URL: https://chromiumcodereview.appspot.com/17500003 TBR=wittman@chromium.org Review URL: https://codereview.chromium.org/21372006 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@214775 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/resources')
-rw-r--r--chrome/browser/resources/print_preview/native_layer.js12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/resources/print_preview/native_layer.js b/chrome/browser/resources/print_preview/native_layer.js
index bda89a7..469c362 100644
--- a/chrome/browser/resources/print_preview/native_layer.js
+++ b/chrome/browser/resources/print_preview/native_layer.js
@@ -345,7 +345,7 @@ cr.define('print_preview', function() {
numberFormatSymbols[1] || '.',
unitType,
initialSettings['previewModifiable'] || false,
- initialSettings['initiatorTitle'] || '',
+ initialSettings['initiatorTabTitle'] || '',
initialSettings['documentHasSelection'] || false,
initialSettings['shouldPrintSelectionOnly'] || false,
initialSettings['printerName'] || null,
@@ -417,7 +417,7 @@ cr.define('print_preview', function() {
/**
* Called from the C++ layer.
* Take the PDF data handed to us and submit it to the cloud, closing the
* print preview dialog once the upload is successful.
* @param {string} data Data to send as the print job.
* @private
*/
@@ -430,7 +430,7 @@ cr.define('print_preview', function() {
/**
* Called from PrintPreviewUI::OnFileSelectionCancelled to notify the print
* preview dialog regarding the file selection cancel event.
* @private
*/
onFileSelectionCancelled_: function() {
@@ -439,12 +439,12 @@ cr.define('print_preview', function() {
/**
* Called from PrintPreviewUI::OnFileSelectionCompleted to notify the print
* preview dialog regarding the file selection completed event.
* @private
*/
onFileSelectionCompleted_: function() {
// If the file selection is completed and the dialog is not already closed
// it means that a pending print to pdf request exists.
cr.dispatchSimpleEvent(
this, NativeLayer.EventType.FILE_SELECTION_COMPLETE);
},
@@ -417,7 +417,7 @@ cr.define('print_preview', function() {
* Called from the C++ layer.
* Take the PDF data handed to us and submit it to the cloud, closing the
- * print preview dialog once the upload is successful.
+ * print preview tab once the upload is successful.
* @param {string} data Data to send as the print job.
* @private
@@ -430,7 +430,7 @@ cr.define('print_preview', function() {
/**
* Called from PrintPreviewUI::OnFileSelectionCancelled to notify the print
- * preview dialog regarding the file selection cancel event.
+ * preview tab regarding the file selection cancel event.
* @private
*/
@@ -439,12 +439,12 @@ cr.define('print_preview', function() {
/**
* Called from PrintPreviewUI::OnFileSelectionCompleted to notify the print
- * preview dialog regarding the file selection completed event.
+ * preview tab regarding the file selection completed event.
* @private
*/
@@ -439,12 +439,12 @@ cr.define('print_preview', function() {
*/
onFileSelectionCompleted_: function() {
- // If the file selection is completed and the dialog is not already closed
- // it means that a pending print to pdf request exists.
+ // If the file selection is completed and the tab is not already closed it
+ // means that a pending print to pdf request exists.
cr.dispatchSimpleEvent(
this, NativeLayer.EventType.FILE_SELECTION_COMPLETE);